@@ -3,7 +3,7 @@
 import token
 from grammar import Grammar
 from translator import Translator
-import tokens
 import special
+from tokens import *
 
 # vim: et sw=4 sts=4
