@@ -10,7 +10,8 @@ def _parse(text):
     return tree
 
 def test_1():
-    assert 5 == m.from_string('2+3')
+    r = m.from_string('2+3')
+    assert 5 == r
 
 def test_2():
     tree = _parse('2+3')
@@ -34,8 +35,9 @@ def test_8():
     assert evaluate('4%3') == 1
 
 if __name__ == '__main__':
-    for name, fn in globals().items():
+    for name, fn in sorted(globals().items()):
         if name.startswith('test_'):
+            print 'testing', name
             fn()
             print 'test passed'
     print 'Finished!'
